pub struct Timeline {
pub parts: Vec<Part>,
pub context_changes: Vec<ContextChange>,
}Expand description
A collection of musical parts that play simultaneously.
Represents the complete musical content at a given level, whether for a full score or a movement within a larger work.
Fields
parts: Vec<Part>context_changes: Vec<ContextChange>Implementations
Sourceimpl Timeline
impl Timeline
pub fn add_part(&mut self, part: Part)
pub fn with_part(self, part: Part) -> Self
pub fn add_parts(&mut self, parts: Vec<Part>)
pub fn with_parts(self, parts: Vec<Part>) -> Self
pub fn add_context_change(&mut self, change: ContextChange)
pub fn with_context_change(self, change: ContextChange) -> Self
pub fn total_duration(&self) -> Fraction