pub struct SetClass;Expand description
Computes the set class of a pitch class set.
A set class contains all transpositions and inversions of a given pitch class set. This function returns all members of the set class.
Arguments
set- A pitch class set or collection of pitch classes/numbers
Returns
A list of pitch class sets representing all members of the set class